@@ -17,11 +17,11 @@ import (
 	"github.com/schollz/cli/v2"
 	"github.com/schollz/croc/v10/src/comm"
 	"github.com/schollz/croc/v10/src/croc"
-	"github.com/schollz/croc/v10/src/mnemonicode"
 	"github.com/schollz/croc/v10/src/models"
 	"github.com/schollz/croc/v10/src/tcp"
 	"github.com/schollz/croc/v10/src/utils"
 	log "github.com/schollz/logger"
+	"github.com/schollz/mnemonicode"
 	"github.com/schollz/pake/v3"
 )
 
@@ -36,15 +36,12 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.2.7"
+		Version = "v10.0.4"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
 	app.Usage = "easily and securely transfer stuff from one computer to another"
-	app.UsageText = `croc [GLOBAL OPTIONS] [COMMAND] [COMMAND OPTIONS] [filename(s) or folder]
-
-   USAGE EXAMPLES:
-   Send a file:
+	app.UsageText = `Send a file:
       croc send file.txt
 
       -git to respect your .gitignore
@@ -77,8 +74,6 @@ func Run() (err error) {
 				&cli.BoolFlag{Name: "git", Usage: "enable .gitignore respect / don't send ignored files"},
 				&cli.IntFlag{Name: "port", Value: 9009, Usage: "base port for the relay"},
 				&cli.IntFlag{Name: "transfers", Value: 4, Usage: "number of ports to use for transfers"},
-				&cli.BoolFlag{Name: "qrcode", Aliases: []string{"qr"}, Usage: "show receive code as a qrcode"},
-				&cli.StringFlag{Name: "exclude", Value: "", Usage: "exclude files if they contain any of the comma separated strings"},
 			},
 			HelpName: "croc send",
 			Action:   send,
@@ -92,14 +87,11 @@ func Run() (err error) {
 			Flags: []cli.Flag{
 				&cli.StringFlag{Name: "host", Usage: "host of the relay"},
 				&cli.StringFlag{Name: "ports", Value: "9009,9010,9011,9012,9013", Usage: "ports of the relay"},
-				&cli.IntFlag{Name: "port", Value: 9009, Usage: "base port for the relay"},
-				&cli.IntFlag{Name: "transfers", Value: 5, Usage: "number of ports to use for relay"},
 			},
 		},
 	}
 	app.Flags = []cli.Flag{
 		&cli.BoolFlag{Name: "internal-dns", Usage: "use a built-in DNS stub resolver rather than the host operating system"},
-		&cli.BoolFlag{Name: "classic", Usage: "toggle between the classic mode (insecure due to local attack vector) and new mode (secure)"},
 		&cli.BoolFlag{Name: "remember", Usage: "save these settings to reuse next time"},
 		&cli.BoolFlag{Name: "debug", Usage: "toggle debug mode"},
 		&cli.BoolFlag{Name: "yes", Usage: "automatically agree to all prompts"},
@@ -108,9 +100,8 @@ func Run() (err error) {
 		&cli.BoolFlag{Name: "ask", Usage: "make sure sender and recipient are prompted"},
 		&cli.BoolFlag{Name: "local", Usage: "force to use only local connections"},
 		&cli.BoolFlag{Name: "ignore-stdin", Usage: "ignore piped stdin"},
-		&cli.BoolFlag{Name: "overwrite", Usage: "do not prompt to overwrite or resume"},
+		&cli.BoolFlag{Name: "overwrite", Usage: "do not prompt to overwrite"},
 		&cli.BoolFlag{Name: "testing", Usage: "flag for testing purposes"},
-		&cli.StringFlag{Name: "multicast", Value: "239.255.255.250", Usage: "multicast address to use for local discovery"},
 		&cli.StringFlag{Name: "curve", Value: "p256", Usage: "choose an encryption curve (" + strings.Join(pake.AvailableCurves(), ", ") + ")"},
 		&cli.StringFlag{Name: "ip", Value: "", Usage: "set sender ip if known e.g. 10.0.0.1:9009, [::1]:9009"},
 		&cli.StringFlag{Name: "relay", Value: models.DEFAULT_RELAY, Usage: "address of the relay", EnvVars: []string{"CROC_RELAY"}},
@@ -119,7 +110,7 @@ func Run() (err error) {
 		&cli.StringFlag{Name: "pass", Value: models.DEFAULT_PASSPHRASE, Usage: "password for the relay", EnvVars: []string{"CROC_PASS"}},
 		&cli.StringFlag{Name: "socks5", Value: "", Usage: "add a socks5 proxy", EnvVars: []string{"SOCKS5_PROXY"}},
 		&cli.StringFlag{Name: "connect", Value: "", Usage: "add a http proxy", EnvVars: []string{"HTTP_PROXY"}},
-		&cli.StringFlag{Name: "throttleUpload", Value: "", Usage: "throttle the upload speed e.g. 500k"},
+		&cli.StringFlag{Name: "throttleUpload", Value: "", Usage: "Throttle the upload speed e.g. 500k"},
 	}
 	app.EnableBashCompletion = true
 	app.HideHelp = false
@@ -134,61 +125,6 @@ func Run() (err error) {
 			return true
 		}
 
-		// check if "classic" is set
-		classicFile := getClassicConfigFile(true)
-		classicInsecureMode := utils.Exists(classicFile)
-		if c.Bool("classic") {
-			if classicInsecureMode {
-				// classic mode not enabled
-				fmt.Print(`Classic mode is currently ENABLED.
-
-Disabling this mode will prevent the shared secret from being visible
-on the host's process list when passed via the command line. On a
-multi-user system, this will help ensure that other local users cannot
-access the shared secret and receive the files instead of the intended
-recipient.
-
-Do you wish to continue to DISABLE the classic mode? (y/N) `)
-				choice := strings.ToLower(utils.GetInput(""))
-				if choice == "y" || choice == "yes" {
-					os.Remove(classicFile)
-					fmt.Print("\nClassic mode DISABLED.\n\n")
-					fmt.Print(`To send and receive, export the CROC_SECRET variable with the code phrase:
-
-  Send:    CROC_SECRET=*** croc send file.txt
-
-  Receive: CROC_SECRET=*** croc` + "\n\n")
-				} else {
-					fmt.Print("\nClassic mode ENABLED.\n")
-
-				}
-			} else {
-				// enable classic mode
-				// touch the file
-				fmt.Print(`Classic mode is currently DISABLED.
-
-Please note that enabling this mode will make the shared secret visible
-on the host's process list when passed via the command line. On a
-multi-user system, this could allow other local users to access the
-shared secret and receive the files instead of the intended recipient.
-
-Do you wish to continue to enable the classic mode? (y/N) `)
-				choice := strings.ToLower(utils.GetInput(""))
-				if choice == "y" || choice == "yes" {
-					fmt.Print("\nClassic mode ENABLED.\n\n")
-					os.WriteFile(classicFile, []byte("enabled"), 0o644)
-					fmt.Print(`To send and receive, use the code phrase:
-
-  Send:    croc send --code *** file.txt
-
-  Receive: croc ***` + "\n\n")
-				} else {
-					fmt.Print("\nClassic mode DISABLED.\n")
-				}
-			}
-			os.Exit(0)
-		}
-
 		// if trying to send but forgot send, let the user know
 		if c.Args().Present() && allStringsAreFiles(c.Args().Slice()) {
 			fnames := []string{}
@@ -202,7 +138,6 @@ Do you wish to continue to enable the classic mode? (y/N) `)
 				return send(c)
 			}
 		}
-
 		return receive(c)
 	}
 
@@ -213,14 +148,6 @@ func setDebugLevel(c *cli.Context) {
 	if c.Bool("debug") {
 		log.SetLevel("debug")
 		log.Debug("debug mode on")
-		// print the public IP address
-		ip, err := utils.PublicIP()
-		if err == nil {
-			log.Debugf("public IP address: %s", ip)
-		} else {
-			log.Debug(err)
-		}
-
 	} else {
 		log.SetLevel("info")
 	}
@@ -235,15 +162,6 @@ func getSendConfigFile(requireValidPath bool) string {
 	return path.Join(configFile, "send.json")
 }
 
-func getClassicConfigFile(requireValidPath bool) string {
-	configFile, err := utils.GetConfigDir(requireValidPath)
-	if err != nil {
-		log.Error(err)
-		return ""
-	}
-	return path.Join(configFile, "classic_enabled")
-}
-
 func getReceiveConfigFile(requireValidPath bool) (string, error) {
 	configFile, err := utils.GetConfigDir(requireValidPath)
 	if err != nil {
@@ -275,13 +193,6 @@ func send(c *cli.Context) (err error) {
 	if transfersParam == 0 {
 		transfersParam = 4
 	}
-	excludeStrings := []string{}
-	for _, v := range strings.Split(c.String("exclude"), ",") {
-		v = strings.ToLower(strings.TrimSpace(v))
-		if v != "" {
-			excludeStrings = append(excludeStrings, v)
-		}
-	}
 
 	ports := make([]string, transfersParam+1)
 	for i := 0; i <= transfersParam; i++ {
@@ -289,31 +200,28 @@ func send(c *cli.Context) (err error) {
 	}
 
 	crocOptions := croc.Options{
-		SharedSecret:     c.String("code"),
-		IsSender:         true,
-		Debug:            c.Bool("debug"),
-		NoPrompt:         c.Bool("yes"),
-		RelayAddress:     c.String("relay"),
-		RelayAddress6:    c.String("relay6"),
-		Stdout:           c.Bool("stdout"),
-		DisableLocal:     c.Bool("no-local"),
-		OnlyLocal:        c.Bool("local"),
-		IgnoreStdin:      c.Bool("ignore-stdin"),
-		RelayPorts:       ports,
-		Ask:              c.Bool("ask"),
-		NoMultiplexing:   c.Bool("no-multi"),
-		RelayPassword:    determinePass(c),
-		SendingText:      c.String("text") != "",
-		NoCompress:       c.Bool("no-compress"),
-		Overwrite:        c.Bool("overwrite"),
-		Curve:            c.String("curve"),
-		HashAlgorithm:    c.String("hash"),
-		ThrottleUpload:   c.String("throttleUpload"),
-		ZipFolder:        c.Bool("zip"),
-		GitIgnore:        c.Bool("git"),
-		ShowQrCode:       c.Bool("qrcode"),
-		MulticastAddress: c.String("multicast"),
-		Exclude:          excludeStrings,
+		SharedSecret:   c.String("code"),
+		IsSender:       true,
+		Debug:          c.Bool("debug"),
+		NoPrompt:       c.Bool("yes"),
+		RelayAddress:   c.String("relay"),
+		RelayAddress6:  c.String("relay6"),
+		Stdout:         c.Bool("stdout"),
+		DisableLocal:   c.Bool("no-local"),
+		OnlyLocal:      c.Bool("local"),
+		IgnoreStdin:    c.Bool("ignore-stdin"),
+		RelayPorts:     ports,
+		Ask:            c.Bool("ask"),
+		NoMultiplexing: c.Bool("no-multi"),
+		RelayPassword:  determinePass(c),
+		SendingText:    c.String("text") != "",
+		NoCompress:     c.Bool("no-compress"),
+		Overwrite:      c.Bool("overwrite"),
+		Curve:          c.String("curve"),
+		HashAlgorithm:  c.String("hash"),
+		ThrottleUpload: c.String("throttleUpload"),
+		ZipFolder:      c.Bool("zip"),
+		GitIgnore:      c.Bool("git"),
 	}
 	if crocOptions.RelayAddress != models.DEFAULT_RELAY {
 		crocOptions.RelayAddress6 = ""
@@ -329,6 +237,9 @@ func send(c *cli.Context) (err error) {
 			return
 		}
 		// update anything that isn't explicitly set
+		if !c.IsSet("relay") && rememberedOptions.RelayAddress != "" {
+			crocOptions.RelayAddress = rememberedOptions.RelayAddress
+		}
 		if !c.IsSet("no-local") {
 			crocOptions.DisableLocal = rememberedOptions.DisableLocal
 		}
@@ -341,6 +252,9 @@ func send(c *cli.Context) (err error) {
 		if !c.IsSet("pass") && rememberedOptions.RelayPassword != "" {
 			crocOptions.RelayPassword = rememberedOptions.RelayPassword
 		}
+		if !c.IsSet("relay6") && rememberedOptions.RelayAddress6 != "" {
+			crocOptions.RelayAddress6 = rememberedOptions.RelayAddress6
+		}
 		if !c.IsSet("overwrite") {
 			crocOptions.Overwrite = rememberedOptions.Overwrite
 		}
@@ -365,7 +279,6 @@ func send(c *cli.Context) (err error) {
 		if err != nil {
 			return
 		}
-		utils.MarkFileForRemoval(fnames[0])
 		defer func() {
 			e := os.Remove(fnames[0])
 			if e != nil {
@@ -377,7 +290,6 @@ func send(c *cli.Context) (err error) {
 		if err != nil {
 			return
 		}
-		utils.MarkFileForRemoval(fnames[0])
 		defer func() {
 			e := os.Remove(fnames[0])
 			if e != nil {
@@ -392,28 +304,22 @@ func send(c *cli.Context) (err error) {
 		return errors.New("must specify file: croc send [filename(s) or folder]")
 	}
 
-	classicInsecureMode := utils.Exists(getClassicConfigFile(true))
-	if !classicInsecureMode {
-		// if operating system is UNIX, then use environmental variable to set the code
-		if (!(runtime.GOOS == "windows") && c.IsSet("code")) || os.Getenv("CROC_SECRET") != "" {
-			crocOptions.SharedSecret = os.Getenv("CROC_SECRET")
-			if crocOptions.SharedSecret == "" {
-				fmt.Printf(`On UNIX systems, to send with a custom code phrase,
+	// if operating system is UNIX, then use environmental variable to set the code
+	if (runtime.GOOS == "linux" && c.IsSet("code")) || os.Getenv("CROC_SECRET") != "" {
+		crocOptions.SharedSecret = os.Getenv("CROC_SECRET")
+		if crocOptions.SharedSecret == "" {
+			fmt.Printf(`On linux, to send with a custom code phrase, 
 you need to set the environmental variable CROC_SECRET:
 
-  CROC_SECRET=**** croc send file.txt
+  export CROC_SECRET="****"
+  croc send file.txt
 
-Or you can have the code phrase automatically generated:
+Or you can have the code phrase automaticlaly generated:
 
   croc send file.txt
 
-Or you can go back to the classic croc behavior by enabling classic mode:
-
-  croc --classic
-
 `)
-				os.Exit(0)
-			}
+			os.Exit(0)
 		}
 	}
 
@@ -421,49 +327,10 @@ Or you can go back to the classic croc behavior by enabling classic mode:
 		// generate code phrase
 		crocOptions.SharedSecret = utils.GetRandomName()
 	}
-	minimalFileInfos, emptyFoldersToTransfer, totalNumberFolders, err := croc.GetFilesInfo(fnames, crocOptions.ZipFolder, crocOptions.GitIgnore, crocOptions.Exclude)
+	minimalFileInfos, emptyFoldersToTransfer, totalNumberFolders, err := croc.GetFilesInfo(fnames, crocOptions.ZipFolder, crocOptions.GitIgnore)
 	if err != nil {
 		return
 	}
-	if len(crocOptions.Exclude) > 0 {
-		minimalFileInfosInclude := []croc.FileInfo{}
-		emptyFoldersToTransferInclude := []croc.FileInfo{}
-		for _, f := range minimalFileInfos {
-			exclude := false
-			for _, exclusion := range crocOptions.Exclude {
-				if strings.Contains(path.Join(strings.ToLower(f.FolderRemote), strings.ToLower(f.Name)), exclusion) {
-					exclude = true
-					break
-				}
-			}
-			if !exclude {
-				minimalFileInfosInclude = append(minimalFileInfosInclude, f)
-			}
-		}
-		for _, f := range emptyFoldersToTransfer {
-			exclude := false
-			for _, exclusion := range crocOptions.Exclude {
-				if strings.Contains(path.Join(strings.ToLower(f.FolderRemote), strings.ToLower(f.Name)), exclusion) {
-					exclude = true
-					break
-				}
-			}
-			if !exclude {
-				emptyFoldersToTransferInclude = append(emptyFoldersToTransferInclude, f)
-			}
-		}
-		totalNumberFolders = 0
-		folderMap := make(map[string]bool)
-		for _, f := range minimalFileInfosInclude {
-			folderMap[f.FolderRemote] = true
-		}
-		for _, f := range emptyFoldersToTransferInclude {
-			folderMap[f.FolderRemote] = true
-		}
-		totalNumberFolders = len(folderMap)
-		minimalFileInfos = minimalFileInfosInclude
-		emptyFoldersToTransfer = emptyFoldersToTransferInclude
-	}
 
 	cr, err := croc.New(crocOptions)
 	if err != nil {
@@ -472,7 +339,9 @@ Or you can go back to the classic croc behavior by enabling classic mode:
 
 	// save the config
 	saveConfig(c, crocOptions)
+
 	err = cr.Send(minimalFileInfos, emptyFoldersToTransfer, totalNumberFolders)
+
 	return
 }
 
@@ -569,21 +438,20 @@ func receive(c *cli.Context) (err error) {
 	comm.Socks5Proxy = c.String("socks5")
 	comm.HttpProxy = c.String("connect")
 	crocOptions := croc.Options{
-		SharedSecret:     c.String("code"),
-		IsSender:         false,
-		Debug:            c.Bool("debug"),
-		NoPrompt:         c.Bool("yes"),
-		RelayAddress:     c.String("relay"),
-		RelayAddress6:    c.String("relay6"),
-		Stdout:           c.Bool("stdout"),
-		Ask:              c.Bool("ask"),
-		RelayPassword:    determinePass(c),
-		OnlyLocal:        c.Bool("local"),
-		IP:               c.String("ip"),
-		Overwrite:        c.Bool("overwrite"),
-		Curve:            c.String("curve"),
-		TestFlag:         c.Bool("testing"),
-		MulticastAddress: c.String("multicast"),
+		SharedSecret:  c.String("code"),
+		IsSender:      false,
+		Debug:         c.Bool("debug"),
+		NoPrompt:      c.Bool("yes"),
+		RelayAddress:  c.String("relay"),
+		RelayAddress6: c.String("relay6"),
+		Stdout:        c.Bool("stdout"),
+		Ask:           c.Bool("ask"),
+		RelayPassword: determinePass(c),
+		OnlyLocal:     c.Bool("local"),
+		IP:            c.String("ip"),
+		Overwrite:     c.Bool("overwrite"),
+		Curve:         c.String("curve"),
+		TestFlag:      c.Bool("testing"),
 	}
 	if crocOptions.RelayAddress != models.DEFAULT_RELAY {
 		crocOptions.RelayAddress6 = ""
@@ -620,6 +488,9 @@ func receive(c *cli.Context) (err error) {
 			return
 		}
 		// update anything that isn't explicitly Globally set
+		if !c.IsSet("relay") && rememberedOptions.RelayAddress != "" {
+			crocOptions.RelayAddress = rememberedOptions.RelayAddress
+		}
 		if !c.IsSet("yes") {
 			crocOptions.NoPrompt = rememberedOptions.NoPrompt
 		}
@@ -629,6 +500,9 @@ func receive(c *cli.Context) (err error) {
 		if !c.IsSet("pass") && rememberedOptions.RelayPassword != "" {
 			crocOptions.RelayPassword = rememberedOptions.RelayPassword
 		}
+		if !c.IsSet("relay6") && rememberedOptions.RelayAddress6 != "" {
+			crocOptions.RelayAddress6 = rememberedOptions.RelayAddress6
+		}
 		if !c.IsSet("overwrite") {
 			crocOptions.Overwrite = rememberedOptions.Overwrite
 		}
@@ -640,28 +514,23 @@ func receive(c *cli.Context) (err error) {
 		}
 	}
 
-	classicInsecureMode := utils.Exists(getClassicConfigFile(true))
 	if crocOptions.SharedSecret == "" && os.Getenv("CROC_SECRET") != "" {
 		crocOptions.SharedSecret = os.Getenv("CROC_SECRET")
-	} else if !(runtime.GOOS == "windows") && crocOptions.SharedSecret != "" && !classicInsecureMode {
+	} else if runtime.GOOS == "linux" && crocOptions.SharedSecret != "" {
 		crocOptions.SharedSecret = os.Getenv("CROC_SECRET")
 		if crocOptions.SharedSecret == "" {
-			fmt.Printf(`On UNIX systems, to receive with croc you either need
+			fmt.Printf(`On linux, to receive with croc you either need 
 to set a code phrase using your environmental variables:
-
-  CROC_SECRET=**** croc
+	
+  export CROC_SECRET="****"
+  croc 
 
 Or you can specify the code phrase when you run croc without
 declaring the secret on the command line:
 
-  croc
+  croc 
   Enter receive code: ****
-
-Or you can go back to the classic croc behavior by enabling classic mode:
-
-  croc --classic
-
-`)
+				`)
 			os.Exit(0)
 		}
 	}
@@ -717,25 +586,7 @@ func relay(c *cli.Context) (err error) {
 		debugString = "debug"
 	}
 	host := c.String("host")
-	var ports []string
-
-	if c.IsSet("ports") {
-		ports = strings.Split(c.String("ports"), ",")
-	} else {
-		portString := c.Int("port")
-		if portString == 0 {
-			portString = 9009
-		}
-		transfersString := c.Int("transfers")
-		if transfersString == 0 {
-			transfersString = 4
-		}
-		ports = make([]string, transfersString)
-		for i := range ports {
-			ports[i] = strconv.Itoa(portString + i)
-		}
-	}
-
+	ports := strings.Split(c.String("ports"), ",")
 	tcpPorts := strings.Join(ports[1:], ",")
 	for i, port := range ports {
 		if i == 0 {
