@@ -11,6 +11,7 @@ import (
 	"encoding/hex"
 	"fmt"
 	"io"
+	"log"
 	"math"
 	"math/big"
 	"net"
@@ -22,12 +23,9 @@ import (
 	"time"
 	"unicode"
 
-	"github.com/cespare/xxhash/v2"
+	"github.com/cespare/xxhash"
 	"github.com/kalafut/imohash"
-	"github.com/minio/highwayhash"
-	"github.com/schollz/croc/v10/src/mnemonicode"
-	log "github.com/schollz/logger"
-	"github.com/schollz/progressbar/v3"
+	"github.com/schollz/mnemonicode"
 )
 
 const NbPinNumbers = 4
@@ -79,11 +77,7 @@ func GetInput(prompt string) string {
 
 // HashFile returns the hash of a file or, in case of a symlink, the
 // SHA256 hash of its target. Takes an argument to specify the algorithm to use.
-func HashFile(fname string, algorithm string, showProgress ...bool) (hash256 []byte, err error) {
-	doShowProgress := false
-	if len(showProgress) > 0 {
-		doShowProgress = showProgress[0]
-	}
+func HashFile(fname string, algorithm string) (hash256 []byte, err error) {
 	var fstats os.FileInfo
 	fstats, err = os.Lstat(fname)
 	if err != nil {
@@ -101,60 +95,16 @@ func HashFile(fname string, algorithm string, showProgress ...bool) (hash256 []b
 	case "imohash":
 		return IMOHashFile(fname)
 	case "md5":
-		return MD5HashFile(fname, doShowProgress)
+		return MD5HashFile(fname)
 	case "xxhash":
-		return XXHashFile(fname, doShowProgress)
-	case "highway":
-		return HighwayHashFile(fname, doShowProgress)
+		return XXHashFile(fname)
 	}
 	err = fmt.Errorf("unspecified algorithm")
 	return
 }
 
-// HighwayHashFile returns highwayhash of a file
-func HighwayHashFile(fname string, doShowProgress bool) (hashHighway []byte, err error) {
-	f, err := os.Open(fname)
-	if err != nil {
-		return
-	}
-	defer f.Close()
-	key, err := hex.DecodeString("1553c5383fb0b86578c3310da665b4f6e0521acf22eb58a99532ffed02a6b115")
-	if err != nil {
-		return
-	}
-	h, err := highwayhash.New(key)
-	if err != nil {
-		err = fmt.Errorf("could not create highwayhash: %s", err.Error())
-		return
-	}
-	if doShowProgress {
-		stat, _ := f.Stat()
-		fnameShort := path.Base(fname)
-		if len(fnameShort) > 20 {
-			fnameShort = fnameShort[:20] + "..."
-		}
-		bar := progressbar.NewOptions64(stat.Size(),
-			progressbar.OptionSetWriter(os.Stderr),
-			progressbar.OptionShowBytes(true),
-			progressbar.OptionSetDescription(fmt.Sprintf("Hashing %s", fnameShort)),
-			progressbar.OptionClearOnFinish(),
-			progressbar.OptionFullWidth(),
-		)
-		if _, err = io.Copy(io.MultiWriter(h, bar), f); err != nil {
-			return
-		}
-	} else {
-		if _, err = io.Copy(h, f); err != nil {
-			return
-		}
-	}
-
-	hashHighway = h.Sum(nil)
-	return
-}
-
 // MD5HashFile returns MD5 hash
-func MD5HashFile(fname string, doShowProgress bool) (hash256 []byte, err error) {
+func MD5HashFile(fname string) (hash256 []byte, err error) {
 	f, err := os.Open(fname)
 	if err != nil {
 		return
@@ -162,42 +112,23 @@ func MD5HashFile(fname string, doShowProgress bool) (hash256 []byte, err error)
 	defer f.Close()
 
 	h := md5.New()
-	if doShowProgress {
-		stat, _ := f.Stat()
-		fnameShort := path.Base(fname)
-		if len(fnameShort) > 20 {
-			fnameShort = fnameShort[:20] + "..."
-		}
-		bar := progressbar.NewOptions64(stat.Size(),
-			progressbar.OptionSetWriter(os.Stderr),
-			progressbar.OptionShowBytes(true),
-			progressbar.OptionSetDescription(fmt.Sprintf("Hashing %s", fnameShort)),
-			progressbar.OptionClearOnFinish(),
-			progressbar.OptionFullWidth(),
-		)
-		if _, err = io.Copy(io.MultiWriter(h, bar), f); err != nil {
-			return
-		}
-	} else {
-		if _, err = io.Copy(h, f); err != nil {
-			return
-		}
+	if _, err = io.Copy(h, f); err != nil {
+		return
 	}
 
 	hash256 = h.Sum(nil)
 	return
 }
 
-var imofull = imohash.NewCustom(0, 0)
-var imopartial = imohash.NewCustom(16*16*8*1024, 128*1024)
-
 // IMOHashFile returns imohash
 func IMOHashFile(fname string) (hash []byte, err error) {
-	b, err := imopartial.SumFile(fname)
+	b, err := imohash.SumFile(fname)
 	hash = b[:]
 	return
 }
 
+var imofull = imohash.NewCustom(0, 0)
+
 // IMOHashFileFull returns imohash of full file
 func IMOHashFileFull(fname string) (hash []byte, err error) {
 	b, err := imofull.SumFile(fname)
@@ -206,7 +137,7 @@ func IMOHashFileFull(fname string) (hash []byte, err error) {
 }
 
 // XXHashFile returns the xxhash of a file
-func XXHashFile(fname string, doShowProgress bool) (hash256 []byte, err error) {
+func XXHashFile(fname string) (hash256 []byte, err error) {
 	f, err := os.Open(fname)
 	if err != nil {
 		return
@@ -214,26 +145,8 @@ func XXHashFile(fname string, doShowProgress bool) (hash256 []byte, err error) {
 	defer f.Close()
 
 	h := xxhash.New()
-	if doShowProgress {
-		stat, _ := f.Stat()
-		fnameShort := path.Base(fname)
-		if len(fnameShort) > 20 {
-			fnameShort = fnameShort[:20] + "..."
-		}
-		bar := progressbar.NewOptions64(stat.Size(),
-			progressbar.OptionSetWriter(os.Stderr),
-			progressbar.OptionShowBytes(true),
-			progressbar.OptionSetDescription(fmt.Sprintf("Hashing %s", fnameShort)),
-			progressbar.OptionClearOnFinish(),
-			progressbar.OptionFullWidth(),
-		)
-		if _, err = io.Copy(io.MultiWriter(h, bar), f); err != nil {
-			return
-		}
-	} else {
-		if _, err = io.Copy(h, f); err != nil {
-			return
-		}
+	if _, err = io.Copy(h, f); err != nil {
+		return
 	}
 
 	hash256 = h.Sum(nil)
@@ -249,21 +162,19 @@ func SHA256(s string) string {
 
 // PublicIP returns public ip address
 func PublicIP() (ip string, err error) {
-	// ask ipv4.icanhazip.com for the public ip
-	// by making http request
-	// if the request fails, return nothing
-	resp, err := http.Get("http://ipv4.icanhazip.com")
+	resp, err := http.Get("https://canhazip.com")
 	if err != nil {
 		return
 	}
 	defer resp.Body.Close()
 
-	// read the body of the response
-	// and return the ip address
-	buf := new(bytes.Buffer)
-	buf.ReadFrom(resp.Body)
-	ip = strings.TrimSpace(buf.String())
-
+	if resp.StatusCode == http.StatusOK {
+		bodyBytes, err := io.ReadAll(resp.Body)
+		if err != nil {
+			return "", err
+		}
+		ip = strings.TrimSpace(string(bodyBytes))
+	}
 	return
 }
 
@@ -271,8 +182,7 @@ func PublicIP() (ip string, err error) {
 func LocalIP() string {
 	conn, err := net.Dial("udp", "8.8.8.8:80")
 	if err != nil {
-		log.Error(err)
-		return ""
+		log.Fatal(err)
 	}
 	defer conn.Close()
 
@@ -281,12 +191,11 @@ func LocalIP() string {
 	return localAddr.IP.String()
 }
 
-// GenerateRandomPin returns a randomly generated pin with set lenght
 func GenerateRandomPin() string {
 	s := ""
 	max := new(big.Int)
 	max.SetInt64(9)
-	for range NbPinNumbers {
+	for i := 0; i < NbPinNumbers; i++ {
 		v, err := rand.Int(rand.Reader, max)
 		if err != nil {
 			panic(err)
@@ -474,12 +383,12 @@ func IsLocalIP(ipaddress string) bool {
 
 func ZipDirectory(destination string, source string) (err error) {
 	if _, err = os.Stat(destination); err == nil {
-		log.Errorf("%s file already exists!\n", destination)
+		log.Fatalf("%s file already exists!\n", destination)
 	}
 	fmt.Fprintf(os.Stderr, "Zipping %s to %s\n", source, destination)
 	file, err := os.Create(destination)
 	if err != nil {
-		log.Error(err)
+		log.Fatalln(err)
 	}
 	defer file.Close()
 	writer := zip.NewWriter(file)
@@ -490,22 +399,22 @@ func ZipDirectory(destination string, source string) (err error) {
 	defer writer.Close()
 	err = filepath.Walk(source, func(path string, info os.FileInfo, err error) error {
 		if err != nil {
-			log.Error(err)
+			log.Fatalln(err)
 		}
 		if info.Mode().IsRegular() {
 			f1, err := os.Open(path)
 			if err != nil {
-				log.Error(err)
+				log.Fatalln(err)
 			}
 			defer f1.Close()
 			zipPath := strings.ReplaceAll(path, source, strings.TrimSuffix(destination, ".zip"))
 			zipPath = filepath.ToSlash(zipPath)
 			w1, err := writer.Create(zipPath)
 			if err != nil {
-				log.Error(err)
+				log.Fatalln(err)
 			}
 			if _, err := io.Copy(w1, f1); err != nil {
-				log.Error(err)
+				log.Fatalln(err)
 			}
 			fmt.Fprintf(os.Stderr, "\r\033[2K")
 			fmt.Fprintf(os.Stderr, "\rAdding %s", zipPath)
@@ -513,7 +422,7 @@ func ZipDirectory(destination string, source string) (err error) {
 		return nil
 	})
 	if err != nil {
-		log.Error(err)
+		log.Fatalln(err)
 	}
 	fmt.Fprintf(os.Stderr, "\n")
 	return nil
@@ -522,7 +431,7 @@ func ZipDirectory(destination string, source string) (err error) {
 func UnzipDirectory(destination string, source string) error {
 	archive, err := zip.OpenReader(source)
 	if err != nil {
-		log.Error(err)
+		log.Fatalln(err)
 	}
 	defer archive.Close()
 
@@ -534,7 +443,7 @@ func UnzipDirectory(destination string, source string) error {
 		// make sure the filepath does not have ".."
 		filePath = filepath.Clean(filePath)
 		if strings.Contains(filePath, "..") {
-			log.Errorf("Invalid file path %s\n", filePath)
+			log.Fatalf("Invalid file path %s\n", filePath)
 		}
 		if f.FileInfo().IsDir() {
 			os.MkdirAll(filePath, os.ModePerm)
@@ -542,7 +451,7 @@ func UnzipDirectory(destination string, source string) error {
 		}
 
 		if err := os.MkdirAll(filepath.Dir(filePath), os.ModePerm); err != nil {
-			log.Error(err)
+			log.Fatalln(err)
 		}
 
 		// check if file exists
@@ -550,23 +459,23 @@ func UnzipDirectory(destination string, source string) error {
 			prompt := fmt.Sprintf("\nOverwrite '%s'? (y/N) ", filePath)
 			choice := strings.ToLower(GetInput(prompt))
 			if choice != "y" && choice != "yes" {
-				fmt.Fprintf(os.Stderr, "Skipping '%s'\n", filePath)
+				fmt.Fprintf(os.Stderr, "skipping '%s'", filePath)
 				continue
 			}
 		}
 
 		dstFile, err := os.OpenFile(filePath, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, f.Mode())
 		if err != nil {
-			log.Error(err)
+			log.Fatalln(err)
 		}
 
 		fileInArchive, err := f.Open()
 		if err != nil {
-			log.Error(err)
+			log.Fatalln(err)
 		}
 
 		if _, err := io.Copy(dstFile, fileInArchive); err != nil {
-			log.Error(err)
+			log.Fatalln(err)
 		}
 
 		dstFile.Close()
@@ -578,64 +487,20 @@ func UnzipDirectory(destination string, source string) error {
 
 // ValidFileName checks if a filename is valid
 // by making sure it has no invisible characters
-func ValidFileName(fname string) (err error) {
-	// make sure it doesn't contain unicode or invisible characters
-	for _, r := range fname {
-		if !unicode.IsGraphic(r) {
-			err = fmt.Errorf("non-graphical unicode: %x U+%d in '%x'", string(r), r, fname)
-			return
+func ValidFileName(fname string) bool {
+	clean1 := strings.Map(func(r rune) rune {
+		if unicode.IsGraphic(r) {
+			return r
 		}
-		if !unicode.IsPrint(r) {
-			err = fmt.Errorf("non-printable unicode: %x U+%d in '%x'", string(r), r, fname)
-			return
+		return -1
+	}, fname)
+
+	clean2 := strings.Map(func(r rune) rune {
+		if unicode.IsPrint(r) {
+			return r
 		}
-	}
-	// make sure basename does not include path separators
-	_, basename := filepath.Split(fname)
-	if strings.Contains(basename, string(os.PathSeparator)) {
-		err = fmt.Errorf("basename cannot contain path separators: '%s'", basename)
-		return
-	}
-	// make sure the filename is not an absolute path
-	if filepath.IsAbs(fname) {
-		err = fmt.Errorf("filename cannot be an absolute path: '%s'", fname)
-		return
-	}
-	if !filepath.IsLocal(fname) {
-		err = fmt.Errorf("filename must be a local path: '%s'", fname)
-		return
-	}
-	return
-}
+		return -1
+	}, fname)
 
-const crocRemovalFile = "croc-marked-files.txt"
-
-func MarkFileForRemoval(fname string) {
-	// append the fname to the list of files to remove
-	f, err := os.OpenFile(crocRemovalFile, os.O_APPEND|os.O_CREATE|os.O_WRONLY, 0o600)
-	if err != nil {
-		log.Debug(err)
-		return
-	}
-	defer f.Close()
-	_, err = f.WriteString(fname + "\n")
-}
-
-func RemoveMarkedFiles() (err error) {
-	// read the file and remove all the files
-	f, err := os.Open(crocRemovalFile)
-	if err != nil {
-		return
-	}
-	defer f.Close()
-	scanner := bufio.NewScanner(f)
-	for scanner.Scan() {
-		fname := scanner.Text()
-		err = os.Remove(fname)
-		if err == nil {
-			log.Tracef("Removed %s", fname)
-		}
-	}
-	os.Remove(crocRemovalFile)
-	return
+	return (fname == clean1) && (fname == clean2)
 }
